@@ -1,4 +1,4 @@
-/*  
+/*
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -12,16 +12,14 @@
 
 char *progname;
 
-TW_INLINE void
-set_progname(char *name) {
-	char *p;
+TW_INLINE void set_progname(char *name) {
+  char *p;
 
-	p = rindex(name, '/');
-	progname = (p ? p+1 : name);
+  p = rindex(name, '/');
+  progname = (p ? p + 1 : name);
 }
 
-TW_INLINE void
-print_version_and_exit(void) {
-	printf(_("%s from %s\n"), progname, "kbd-" VERSION);
-	exit(0);
+TW_INLINE void print_version_and_exit(void) {
+  printf(_("%s from %s\n"), progname, "kbd-" VERSION);
+  exit(0);
 }
