@@ -6,11 +6,10 @@
  *  (at your option) any later version.
  *
  */
-#ifndef _TW_TERM_H
-#define _TW_TERM_H
+#ifndef TW_TERM_H
+#define TW_TERM_H
 
 extern uldat max_fds;
 extern fd_set save_rfds;
 
-
 #endif
