@@ -18,23 +18,31 @@
 #ifndef MD5_H
 #define MD5_H
 
-#ifdef __alpha
-typedef unsigned int uint32;
-#else
-typedef unsigned long uint32;
+#include "twautoconf.h"  /* TW_HAVE_*, uint32_t */
+#include <Tw/compiler.h> /* TW_INLINE, TW_CONST */
+
+#ifdef TW_HAVE_STDINT_H
+#include <stdint.h> /* uint32_t */
 #endif
 
+#ifdef TW_HAVE_STDDEF_H
+#include <stddef.h> /* size_t */
+#endif
+
+typedef uint32_t md5_uint32;
+
+typedef char assert_md5_uint32_is_really_32_bits_wide[sizeof(md5_uint32) == 4 ? 1 : -1];
+
 struct MD5Context {
-	uint32 buf[4];
-	uint32 bits[2];
-	unsigned char in[64];
+  md5_uint32 buf[4];
+  md5_uint32 bits[2];
+  md5_uint32 in[16];
 };
 
 void MD5Init(struct MD5Context *context);
-void MD5Update(struct MD5Context *context, unsigned char const *buf,
-	       unsigned len);
+void MD5Update(struct MD5Context *context, void TW_CONST *mem, size_t len);
 void MD5Final(unsigned char digest[16], struct MD5Context *context);
-void MD5Transform(uint32 buf[4], uint32 const in[16]);
+void MD5Transform(md5_uint32 buf[4], md5_uint32 TW_CONST in[16]);
 
 /*
  * This is needed to make RSAREF happy on some MS-DOS compilers.
