@@ -11,11 +11,11 @@
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
- * 
+ *
  */
 
-#ifndef _TT_TYPES_H
-#define _TT_TYPES_H
+#ifndef TT_TYPES_H
+#define TT_TYPES_H
 
 #include <Tw/Tw_defs.h>
 #include <Tw/Twtypes.h>
@@ -37,5 +37,4 @@
 #include "tree_m4.h"
 #include "decls_m4.h"
 
-#endif /* _TT_TYPES_H */
-
+#endif /* TT_TYPES_H */
