@@ -6,8 +6,11 @@
  * (at your option) any later version.
  *
  */
-#ifndef _TWIN_BUILTIN_H
-#define _TWIN_BUILTIN_H
+#ifndef TWIN_BUILTIN_H
+#define TWIN_BUILTIN_H
+
+#include "obj/fwd.h"
+#include <Tw/datatypes.h>
 
 byte InitBuiltin(void);
 void FillButtonWin(void);
@@ -16,4 +19,4 @@ void UpdateOptionWin(void);
 extern window WinList, MessagesWin;
 extern msgport Builtin_MsgPort;
 
-#endif /* _TWIN_BUILTIN_H */
+#endif /* TWIN_BUILTIN_H */
