@@ -6,26 +6,26 @@
  * (at your option) any later version.
  *
  */
-#ifndef _TWIN_DL_H
-#define _TWIN_DL_H
+#ifndef TWIN_DL_H
+#define TWIN_DL_H
 
 byte DlOpen(module Module);
 void DlClose(module Module);
 
-#define MainSo		((uldat)0)
-#define WMSo		((uldat)1)
-#define TermSo		((uldat)2)
-#define SocketSo	((uldat)3)
-#define RCParseSo	((uldat)4)
-#define MAX_So		((uldat)5)
+#define MainSo ((uldat)0)
+#define WMSo ((uldat)1)
+#define TermSo ((uldat)2)
+#define SocketSo ((uldat)3)
+#define RCParseSo ((uldat)4)
+#define MAX_So ((uldat)5)
 
 module DlLoad(uldat code);
-void   DlUnLoad(uldat code);
+void DlUnload(uldat code);
 module DlIsLoaded(uldat code);
-udat   DlName2Code(byte *name);
+udat DlName2Code(const char *name);
 
-module DlLoadAny(uldat len, byte *name);
+module DlLoadAny(uldat len, const char *name);
 
-void *DlSym(module Module, CONST byte *name);
+void *DlSym(module Module, const char *name);
 
-#endif /* _TWIN_DL_H */
+#endif /* TWIN_DL_H */
