@@ -6,8 +6,8 @@
  * (at your option) any later version.
  *
  */
-#ifndef _TWIN_HW_MULTI_H
-#define _TWIN_HW_MULTI_H
+#ifndef TWIN_HW_MULTI_H
+#define TWIN_HW_MULTI_H
 
 /*
  * this file exports functions and variables defined in hw_multi.c
@@ -17,10 +17,10 @@
 extern byte StrategyFlag;
 extern tany StrategyDelay;
 /* strategy */
-#define HW_UNSET  0
-#define HW_ACCEL  1
+#define HW_UNSET 0
+#define HW_ACCEL 1
 #define HW_BUFFER 2
-#define HW_DELAY  3
+#define HW_DELAY 3
 
 void StrategyReset(void);
 byte Strategy4Video(dat Xstart, dat Ystart, dat Xend, dat Yend);
@@ -34,10 +34,10 @@ void QuitHW(void);
 byte RestartHW(byte verbose);
 void SuspendHW(byte verbose);
 
-display_hw AttachDisplayHW(uldat len, CONST byte *arg, uldat slot, byte flags);
-byte DetachDisplayHW(uldat len, CONST byte *arg, byte flags);
+display_hw AttachDisplayHW(uldat len, const char *arg, uldat slot, byte flags);
+byte DetachDisplayHW(uldat len, const char *arg, byte flags);
 
-void FillVideo(dat Xstart, dat Ystart, dat Xend, dat Yend, hwattr Attrib);
+void FillVideo(dat Xstart, dat Ystart, dat Xend, dat Yend, tcell Attr);
 void RefreshVideo(void);
 byte ResizeDisplay(void);
 
@@ -47,7 +47,6 @@ void UpdateFlagsHW(void);
 void EnableMouseMotionEvents(byte enable);
 
 byte StdAddMouseEvent(udat Code, dat MouseX, dat MouseY);
-void SyntheticKey(widget W, udat Code, udat ShiftFlags, byte Len, byte *Seq);
-
-#endif /* _TWIN_HW_MULTI_H */
+void SyntheticKey(widget W, udat Code, udat ShiftFlags, byte Len, const char *Seq);
 
+#endif /* TWIN_HW_MULTI_H */
