@@ -7,12 +7,12 @@
  *
  */
 
-#ifndef _TWIN_HW_PRIVATE_H
-#define _TWIN_HW_PRIVATE_H
+#ifndef TWIN_HW_PRIVATE_H
+#define TWIN_HW_PRIVATE_H
 
 /*
  * this file exports "private" stuff from hw.c,
- * i.e. intended to be used only by HW/hw_*.c drivers
+ * i.e. intended to be used only by hw/hw_*.c drivers
  */
 
 extern dat (*ChangedVideo)[2][2];
@@ -25,18 +25,17 @@ extern dat DisplayWidth, DisplayHeight;
 
 extern struct termios ttysave;
 
-void FillOldVideo(dat Xstart, dat Ystart, dat Xend, dat Yend, hwattr Attr);
+void FillOldVideo(dat Xstart, dat Ystart, dat Xend, dat Yend, tcell Attr);
 void saveDisplaySize(void);
 
 void NeedRedrawVideo(dat Left, dat Up, dat Right, dat Down);
 
 extern display_hw HW;
-	    
-#define SaveHW	display_hw s_hw = HW
 
-#define SetHW(hw)	(HW = (hw))
+#define SaveHW display_hw s_hw = HW
 
-#define RestoreHW	(HW = s_hw)
-	
-#endif /* _TWIN_HW_PRIVATE_H */
+#define SetHW(hw) (HW = (hw))
 
+#define RestoreHW (HW = s_hw)
+
+#endif /* TWIN_HW_PRIVATE_H */
