@@ -6,16 +6,19 @@
  * (at your option) any later version.
  *
  */
-#ifndef _TWIN_PRINTK_H
-#define _TWIN_PRINTK_H
+#ifndef TWIN_PRINTK_H
+#define TWIN_PRINTK_H
 
-int printk(CONST byte *format, ...);
-void printk_str(int len, CONST byte *s);
+#ifndef SS
+#define SS "%." STR(TW_SMALLBUFF) "s"
+#endif
+
+int printk(const char *format, ...);
+void printk_str(int len, const char *s);
 int printk_receive_fd(int fd);
 int flushk(void);
 
 byte RegisterPrintk(int fd);
 void UnRegisterPrintk(void);
 
-
-#endif /* _TWIN_PRINTK_H */
+#endif /* TWIN_PRINTK_H */
