@@ -6,23 +6,23 @@
  * (at your option) any later version.
  *
  */
-#ifndef _TWIN_RCRUN_H
-#define _TWIN_RCRUN_H
+#ifndef TWIN_RCRUN_H
+#define TWIN_RCRUN_H
 
 #define GLOBAL_MAX 7
 extern node Globals[GLOBAL_MAX];
 extern byte GlobalsAreStatic;
 
-#define CallList	Globals[0]
-#define FuncList	Globals[1]
-#define MenuList	Globals[2]
+#define CallList Globals[0]
+#define FuncList Globals[1]
+#define MenuList Globals[2]
 
-#define ScreenList	Globals[3]
-#define ScreenIndex	3
+#define ScreenList Globals[3]
+#define ScreenIndex 3
 
-#define BorderList	Globals[4]
-#define KeyList		Globals[5]
-#define MouseList	Globals[6]
+#define BorderList Globals[4]
+#define KeyList Globals[5]
+#define MouseList Globals[6]
 
 extern node *MenuBinds; /* array of pointers to nodes inside MenuList */
 extern udat MenuBindsMax;
@@ -30,13 +30,11 @@ extern udat MenuBindsMax;
 byte InitRC(void);
 void QuitRC(void);
 
-node LookupNodeName(str name, node head);
+node LookupNodeName(cstr name, node head);
 
-hwfont *RCFindBorderPattern(window W, byte Border);
+trune *RCFindBorderPattern(window W, byte Border);
 
 byte RC_VM(timevalue *t);
-byte RC_VMQueue(CONST wm_ctx *C);
-
-
-#endif /* _TWIN_RCRUN_H */
+byte RC_VMQueue(const wm_ctx *C);
 
+#endif /* TWIN_RCRUN_H */
