@@ -6,10 +6,10 @@
  * (at your option) any later version.
  *
  */
-#ifndef _TWIN_SOCKET_H
-#define _TWIN_SOCKET_H
+#ifndef TWIN_SOCKET_H
+#define TWIN_SOCKET_H
 
 byte InitSocket(void);
 void QuitSocket(void);
 
-#endif /* _TWIN_SOCKET_H */
+#endif /* TWIN_SOCKET_H */
