@@ -6,11 +6,11 @@
  * (at your option) any later version.
  *
  */
-#ifndef _TWIN_TTERM_H
-#define _TWIN_TTERM_H
+#ifndef TWIN_TTERM_H
+#define TWIN_TTERM_H
 
 byte InitTerm(void);
 
 extern menu Term_Menu;
 
-#endif /* _TWIN_TTERM_H */
+#endif /* TWIN_TTERM_H */
