@@ -6,27 +6,26 @@
  * (at your option) any later version.
  *
  */
-#ifndef _TWIN_WM_H
-#define _TWIN_WM_H
+#ifndef TWIN_WM_H
+#define TWIN_WM_H
 
 typedef struct wm_ctx wm_ctx;
 
 struct wm_ctx {
-    widget W;  /* top level widget user is interacting with */
-    screen Screen;
-    menu Menu;
-    menuitem Item;
-    widget DW; /* deepest widget user is interacting with */
-    udat Type; /* Msg->Type: MSG_* */
-    byte Pos;  /* POS_* relative to (W) */
-    byte ByMouse;
-    udat Code; /* keyboard key / mouse buttons pressed */
-    udat ShiftFlags;
-    dat i, j;  /* mouse coordinates */
-    ldat Left, Up, Rgt, Dwn; /* window (W) corners */
+  widget W; /* top level widget user is interacting with */
+  screen Screen;
+  menu Menu;
+  menuitem Item;
+  widget DW; /* deepest widget user is interacting with */
+  udat Type; /* Msg->Type: MSG_* */
+  byte Pos;  /* POS_* relative to (W) */
+  byte ByMouse;
+  udat Code; /* keyboard key / mouse buttons pressed */
+  udat ShiftFlags;
+  dat i, j;                /* mouse coordinates */
+  ldat Left, Up, Rgt, Dwn; /* window (W) corners */
 };
 
-
 byte InitWM(void);
 
 void AskCloseWidget(widget W);
@@ -37,6 +36,6 @@ void ShowWinList(wm_ctx *C);
 void FocusCtx(wm_ctx *C);
 byte ActivateCtx(wm_ctx *C, byte State);
 
-void ForceRelease(CONST wm_ctx *C);
+void ForceRelease(const wm_ctx *C);
 
-#endif /* _TWIN_WM_H */
+#endif /* TWIN_WM_H */
